@@ -769,10 +769,11 @@ gdk_pixbuf__xpm_image_load_increment (gpointer data,
        g_return_val_if_fail (data != NULL, FALSE);
 
        if (fwrite (buf, sizeof (guchar), size, context->file) != size) {
+	       gint save_errno = errno;
                context->all_okay = FALSE;
                g_set_error (error,
                             G_FILE_ERROR,
-                            g_file_error_from_errno (errno),
+                            g_file_error_from_errno (save_errno),
                             _("Failed to write to temporary file when loading XPM image"));
                return FALSE;
        }
@@ -780,6 +781,12 @@ gdk_pixbuf__xpm_image_load_increment (gpointer data,
        return TRUE;
 }
 
+#ifndef INCLUDE_xpm
+#define MODULE_ENTRY(type,function) function
+#else
+#define MODULE_ENTRY(type,function) _gdk_pixbuf__ ## type ## _ ## function
+#endif
+
 void
 MODULE_ENTRY (xpm, fill_vtable) (GdkPixbufModule *module)
 {
