@@ -600,7 +600,9 @@ _gdk_windowing_window_destroy (GdkWindow *window,
   impl = GDK_WINDOW_IMPL_DIRECTFB (private->impl);
 
   _gdk_selection_window_destroyed (window);
-
+#if (DIRECTFB_MAJOR_VERSION >= 1)
+  gdk_directfb_event_windows_remove (window);
+#endif
   if (window == _gdk_directfb_pointer_grab_window)
     gdk_pointer_ungrab (GDK_CURRENT_TIME);
   if (window == _gdk_directfb_keyboard_grab_window)
@@ -2409,7 +2411,7 @@ gdk_window_set_functions (GdkWindow     *window,
     return;
 
   /* N/A */
-  g_message("unimplemented %s", G_GNUC_FUNCTION);
+  g_message("unimplemented %s", G_STRLOC);
 }
 
 void
@@ -2442,7 +2444,7 @@ gdk_window_set_static_gravities (GdkWindow *window,
     return FALSE;
 
   /* N/A */
-  g_message("unimplemented %s", G_GNUC_FUNCTION);
+  g_message("unimplemented %s", G_STRLOC);
 
   return FALSE;
 }
@@ -2460,7 +2462,7 @@ gdk_window_begin_resize_drag (GdkWindow     *window,
   if (GDK_WINDOW_DESTROYED (window))
     return;
 
-  g_message("unimplemented %s", G_GNUC_FUNCTION);
+  g_message("unimplemented %s", G_STRLOC);
 }
 
 void
@@ -2475,7 +2477,7 @@ gdk_window_begin_move_drag (GdkWindow *window,
   if (GDK_WINDOW_DESTROYED (window))
     return;
 
-  g_message("unimplemented %s", G_GNUC_FUNCTION);
+  g_message("unimplemented %s", G_STRLOC);
 }
 
 /**
@@ -3017,20 +3019,6 @@ gdk_window_beep (GdkWindow *window)
   gdk_display_beep (gdk_display_get_default());
 }
 
-/**
- * gdk_window_set_opacity:
- * @window a top-level #GdkWindow
- * @opacity: opacity
- *
- * Request the windowing system to make @window partially transparent,
- * with opacity 0 being fully transparent and 1 fully opaque. (Values
- * of the opacity parameter are clamped to the [0,1] range.) On X11
- * this works only on X screens with a compositing manager running.
- *
- * For setting up per-pixel alpha, see gdk_screen_get_rgba_colormap().
- *
- * Since: 2.12
- */
 void
 gdk_window_set_opacity (GdkWindow *window,
 			gdouble    opacity)
@@ -3052,6 +3040,14 @@ gdk_window_set_opacity (GdkWindow *window,
   cardinal = opacity * 0xff;
   gdk_directfb_window_set_opacity(window,cardinal);
 }
+
+void
+_gdk_windowing_window_set_composited (GdkWindow *window,
+                                      gboolean   composited)
+{
+}
+
+
 #define __GDK_WINDOW_X11_C__
 #include "gdkaliasdef.c"
 
