@@ -64,6 +64,15 @@
   if (!(private->event_mask & GDK_EXPOSURE_MASK))
     return;
 
+  /* For some reason, we occasionally get draw requests for zero sized rects
+   * at 0,0, just ignore those.
+   */
+  if (rect.origin.x == 0 && rect.origin.y == 0 &&
+      rect.size.width == 0 && rect.size.height == 0)
+    {
+      return;
+    }
+
   GDK_QUARTZ_ALLOC_POOL;
 
   [self getRectsBeingDrawn:&drawn_rects count:&count];
@@ -107,9 +116,20 @@
 
   gdk_region_destroy (region);
 
+  if (needsInvalidateShadow)
+    {
+      [[self window] invalidateShadow];
+      needsInvalidateShadow = NO;
+    }
+
   GDK_QUARTZ_RELEASE_POOL;
 }
 
+-(void)setNeedsInvalidateShadow:(BOOL)invalidate
+{
+  needsInvalidateShadow = invalidate;
+}
+
 /* For information on setting up tracking rects properly, see here:
  * http://developer.apple.com/documentation/Cocoa/Conceptual/EventOverview/EventOverview.pdf
  */
@@ -132,7 +152,7 @@
    * NSPointInRect ([[self window] convertScreenToBase:[NSEvent mouseLocation]], rect)
    */
 
-  rect = NSMakeRect (0, 0, impl->width, impl->height);
+  rect = [self bounds];
   trackingRect = [self addTrackingRect:rect
                                  owner:self
                               userData:nil
@@ -156,9 +176,9 @@
     }
 }
 
--(void)setBounds:(NSRect)bounds
+-(void)setFrame:(NSRect)frame
 {
-  [super setBounds:bounds];
+  [super setFrame:frame];
   [self updateTrackingRect];
 }
 
