@@ -314,13 +314,15 @@ gtk_container_buildable_add_child (GtkBuildable  *buildable,
 
 static void
 gtk_container_buildable_set_child_property (GtkContainer *container,
+					    GtkBuilder   *builder,
 					    GtkWidget    *child,
 					    gchar        *name,
 					    const gchar  *value)
 {
   GParamSpec *pspec;
   GValue gvalue = { 0, };
-
+  GError *error = NULL;
+  
   pspec = gtk_container_class_find_child_property
     (G_OBJECT_GET_CLASS (container), name);
   if (!pspec)
@@ -330,13 +332,15 @@ gtk_container_buildable_set_child_property (GtkContainer *container,
       return;
     }
 
-  if (!gtk_builder_value_from_string (pspec, value, &gvalue))
+  if (!gtk_builder_value_from_string (builder, pspec, value, &gvalue, &error))
     {
-      g_warning ("Could not read property %s:%s with value %s of type %s",
+      g_warning ("Could not read property %s:%s with value %s of type %s: %s",
 		 g_type_name (G_OBJECT_TYPE (container)),
 		 name,
 		 value,
-		 g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)));
+		 g_type_name (G_PARAM_SPEC_VALUE_TYPE (pspec)),
+		 error->message);
+      g_error_free (error);
       return;
     }
 
@@ -385,6 +389,7 @@ attributes_text_element (GMarkupParseContext *context,
     return;
 
   gtk_container_buildable_set_child_property (parser_data->container,
+					      parser_data->builder,
 					      parser_data->child,
 					      parser_data->child_prop_name,
 					      text);
@@ -1078,8 +1083,9 @@ gtk_container_get_property (GObject         *object,
  * #GtkWindow; because toplevel windows can't leave space outside,
  * they leave the space inside. The border is added on all sides of
  * the container. To add space to only one side, one approach is to
- * create a #GtkAlignment widget, call gtk_widget_set_usize() to give
- * it a size, and place it on the side of the container as a spacer.
+ * create a #GtkAlignment widget, call gtk_widget_set_size_request()
+ * to give it a size, and place it on the side of the container as
+ * a spacer.
  **/
 void
 gtk_container_set_border_width (GtkContainer *container,
