@@ -441,7 +441,8 @@ gtk_handle_box_realize (GtkWidget *widget)
 			   GDK_LEAVE_NOTIFY_MASK |
 			   GDK_FOCUS_CHANGE_MASK |
 			   GDK_STRUCTURE_MASK);
-  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+  attributes.type_hint = GDK_WINDOW_TYPE_HINT_TOOLBAR;
+  attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP | GDK_WA_TYPE_HINT;
   hb->float_window = gdk_window_new (gtk_widget_get_root_window (widget),
 				     &attributes, attributes_mask);
   gdk_window_set_user_data (hb->float_window, widget);
@@ -540,7 +541,7 @@ gtk_handle_box_size_request (GtkWidget      *widget,
     }
 
   /* if our child is not visible, we still request its size, since we
-   * won't have any usefull hint for our size otherwise.
+   * won't have any useful hint for our size otherwise.
    */
   if (bin->child)
     gtk_widget_size_request (bin->child, &child_requisition);
@@ -744,12 +745,12 @@ gtk_handle_box_draw_ghost (GtkHandleBox *hb)
 
 static void
 draw_textured_frame (GtkWidget *widget, GdkWindow *window, GdkRectangle *rect, GtkShadowType shadow,
-		     GdkRectangle *clip)
+		     GdkRectangle *clip, GtkOrientation orientation)
 {
    gtk_paint_handle (widget->style, window, GTK_STATE_NORMAL, shadow,
 		     clip, widget, "handlebox",
 		     rect->x, rect->y, rect->width, rect->height, 
-		     GTK_ORIENTATION_VERTICAL);
+		     orientation);
 }
 
 void
@@ -857,10 +858,11 @@ gtk_handle_box_paint (GtkWidget      *widget,
 {
   GtkBin *bin;
   GtkHandleBox *hb;
-  guint width, height;
+  gint width, height;
   GdkRectangle rect;
   GdkRectangle dest;
   gint handle_position;
+  GtkOrientation handle_orientation;
 
   bin = GTK_BIN (widget);
   hb = GTK_HANDLE_BOX (widget);
@@ -899,31 +901,39 @@ gtk_handle_box_paint (GtkWidget      *widget,
       rect.y = 0; 
       rect.width = DRAG_HANDLE_SIZE;
       rect.height = height;
+      handle_orientation = GTK_ORIENTATION_VERTICAL;
       break;
     case GTK_POS_RIGHT:
       rect.x = width - DRAG_HANDLE_SIZE; 
       rect.y = 0;
       rect.width = DRAG_HANDLE_SIZE;
       rect.height = height;
+      handle_orientation = GTK_ORIENTATION_VERTICAL;
       break;
     case GTK_POS_TOP:
       rect.x = 0;
       rect.y = 0; 
       rect.width = width;
       rect.height = DRAG_HANDLE_SIZE;
+      handle_orientation = GTK_ORIENTATION_HORIZONTAL;
       break;
     case GTK_POS_BOTTOM:
       rect.x = 0;
       rect.y = height - DRAG_HANDLE_SIZE;
       rect.width = width;
       rect.height = DRAG_HANDLE_SIZE;
+      handle_orientation = GTK_ORIENTATION_HORIZONTAL;
+      break;
+    default: 
+      g_assert_not_reached ();
       break;
     }
 
   if (gdk_rectangle_intersect (event ? &event->area : area, &rect, &dest))
     draw_textured_frame (widget, hb->bin_window, &rect,
 			 GTK_SHADOW_OUT,
-			 event ? &event->area : area);
+			 event ? &event->area : area,
+			 handle_orientation);
 
   if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
     (* GTK_WIDGET_CLASS (gtk_handle_box_parent_class)->expose_event) (widget, event);
