@@ -9,4 +9,7 @@
 #define P_(String) (String)
 #endif
 
+/* not really I18N-related, but also a string marker macro */
+#define I_(string) g_intern_static_string (string)
+
 #endif
