@@ -118,7 +118,15 @@ extern void _gtk_marshal_BOOLEAN__OBJECT_STRING_STRING (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* BOOLEAN:INT (./gtkmarshalers.list:38) */
+/* BOOLEAN:OBJECT,ENUM (./gtkmarshalers.list:38) */
+extern void _gtk_marshal_BOOLEAN__OBJECT_ENUM (GClosure     *closure,
+                                               GValue       *return_value,
+                                               guint         n_param_values,
+                                               const GValue *param_values,
+                                               gpointer      invocation_hint,
+                                               gpointer      marshal_data);
+
+/* BOOLEAN:INT (./gtkmarshalers.list:39) */
 extern void _gtk_marshal_BOOLEAN__INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -126,7 +134,7 @@ extern void _gtk_marshal_BOOLEAN__INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* BOOLEAN:INT,INT (./gtkmarshalers.list:39) */
+/* BOOLEAN:INT,INT (./gtkmarshalers.list:40) */
 extern void _gtk_marshal_BOOLEAN__INT_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -134,7 +142,7 @@ extern void _gtk_marshal_BOOLEAN__INT_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* BOOLEAN:INT,INT,INT (./gtkmarshalers.list:40) */
+/* BOOLEAN:INT,INT,INT (./gtkmarshalers.list:41) */
 extern void _gtk_marshal_BOOLEAN__INT_INT_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -142,7 +150,15 @@ extern void _gtk_marshal_BOOLEAN__INT_INT_INT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* BOOLEAN:UINT (./gtkmarshalers.list:41) */
+/* BOOLEAN:INT,INT,BOOLEAN,OBJECT (./gtkmarshalers.list:42) */
+extern void _gtk_marshal_BOOLEAN__INT_INT_BOOLEAN_OBJECT (GClosure     *closure,
+                                                          GValue       *return_value,
+                                                          guint         n_param_values,
+                                                          const GValue *param_values,
+                                                          gpointer      invocation_hint,
+                                                          gpointer      marshal_data);
+
+/* BOOLEAN:UINT (./gtkmarshalers.list:43) */
 extern void _gtk_marshal_BOOLEAN__UINT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -150,7 +166,7 @@ extern void _gtk_marshal_BOOLEAN__UINT (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* BOOLEAN:VOID (./gtkmarshalers.list:42) */
+/* BOOLEAN:VOID (./gtkmarshalers.list:44) */
 extern void _gtk_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -158,7 +174,7 @@ extern void _gtk_marshal_BOOLEAN__VOID (GClosure     *closure,
                                         gpointer      invocation_hint,
                                         gpointer      marshal_data);
 
-/* BOOLEAN:BOOLEAN (./gtkmarshalers.list:43) */
+/* BOOLEAN:BOOLEAN (./gtkmarshalers.list:45) */
 extern void _gtk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -166,10 +182,10 @@ extern void _gtk_marshal_BOOLEAN__BOOLEAN (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* BOOLEAN:NONE (./gtkmarshalers.list:44) */
+/* BOOLEAN:NONE (./gtkmarshalers.list:46) */
 #define _gtk_marshal_BOOLEAN__NONE	_gtk_marshal_BOOLEAN__VOID
 
-/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (./gtkmarshalers.list:45) */
+/* BOOLEAN:BOOLEAN,BOOLEAN,BOOLEAN (./gtkmarshalers.list:47) */
 extern void _gtk_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                            GValue       *return_value,
                                                            guint         n_param_values,
@@ -177,7 +193,7 @@ extern void _gtk_marshal_BOOLEAN__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure
                                                            gpointer      invocation_hint,
                                                            gpointer      marshal_data);
 
-/* BOOLEAN:STRING (./gtkmarshalers.list:46) */
+/* BOOLEAN:STRING (./gtkmarshalers.list:48) */
 extern void _gtk_marshal_BOOLEAN__STRING (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -185,7 +201,7 @@ extern void _gtk_marshal_BOOLEAN__STRING (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* ENUM:ENUM (./gtkmarshalers.list:47) */
+/* ENUM:ENUM (./gtkmarshalers.list:49) */
 extern void _gtk_marshal_ENUM__ENUM (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -193,7 +209,7 @@ extern void _gtk_marshal_ENUM__ENUM (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* ENUM:VOID (./gtkmarshalers.list:48) */
+/* ENUM:VOID (./gtkmarshalers.list:50) */
 extern void _gtk_marshal_ENUM__VOID (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -201,7 +217,7 @@ extern void _gtk_marshal_ENUM__VOID (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* INT:POINTER (./gtkmarshalers.list:49) */
+/* INT:POINTER (./gtkmarshalers.list:51) */
 extern void _gtk_marshal_INT__POINTER (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -209,19 +225,19 @@ extern void _gtk_marshal_INT__POINTER (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* NONE:BOOLEAN (./gtkmarshalers.list:50) */
+/* NONE:BOOLEAN (./gtkmarshalers.list:52) */
 #define _gtk_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
 #define _gtk_marshal_NONE__BOOLEAN	_gtk_marshal_VOID__BOOLEAN
 
-/* NONE:ENUM (./gtkmarshalers.list:51) */
+/* NONE:ENUM (./gtkmarshalers.list:53) */
 #define _gtk_marshal_VOID__ENUM	g_cclosure_marshal_VOID__ENUM
 #define _gtk_marshal_NONE__ENUM	_gtk_marshal_VOID__ENUM
 
-/* NONE:INT (./gtkmarshalers.list:52) */
+/* NONE:INT (./gtkmarshalers.list:54) */
 #define _gtk_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
 #define _gtk_marshal_NONE__INT	_gtk_marshal_VOID__INT
 
-/* NONE:INT,BOOL (./gtkmarshalers.list:53) */
+/* NONE:INT,BOOL (./gtkmarshalers.list:55) */
 extern void _gtk_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -230,7 +246,7 @@ extern void _gtk_marshal_VOID__INT_BOOLEAN (GClosure     *closure,
                                             gpointer      marshal_data);
 #define _gtk_marshal_NONE__INT_BOOL	_gtk_marshal_VOID__INT_BOOLEAN
 
-/* NONE:INT,INT (./gtkmarshalers.list:54) */
+/* NONE:INT,INT (./gtkmarshalers.list:56) */
 extern void _gtk_marshal_VOID__INT_INT (GClosure     *closure,
                                         GValue       *return_value,
                                         guint         n_param_values,
@@ -239,11 +255,11 @@ extern void _gtk_marshal_VOID__INT_INT (GClosure     *closure,
                                         gpointer      marshal_data);
 #define _gtk_marshal_NONE__INT_INT	_gtk_marshal_VOID__INT_INT
 
-/* NONE:NONE (./gtkmarshalers.list:55) */
+/* NONE:NONE (./gtkmarshalers.list:57) */
 #define _gtk_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 #define _gtk_marshal_NONE__NONE	_gtk_marshal_VOID__VOID
 
-/* NONE:STRING,INT,POINTER (./gtkmarshalers.list:56) */
+/* NONE:STRING,INT,POINTER (./gtkmarshalers.list:58) */
 extern void _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -252,7 +268,7 @@ extern void _gtk_marshal_VOID__STRING_INT_POINTER (GClosure     *closure,
                                                    gpointer      marshal_data);
 #define _gtk_marshal_NONE__STRING_INT_POINTER	_gtk_marshal_VOID__STRING_INT_POINTER
 
-/* OBJECT:VOID (./gtkmarshalers.list:57) */
+/* OBJECT:VOID (./gtkmarshalers.list:59) */
 extern void _gtk_marshal_OBJECT__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -260,7 +276,7 @@ extern void _gtk_marshal_OBJECT__VOID (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* STRING:DOUBLE (./gtkmarshalers.list:58) */
+/* STRING:DOUBLE (./gtkmarshalers.list:60) */
 extern void _gtk_marshal_STRING__DOUBLE (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -268,12 +284,12 @@ extern void _gtk_marshal_STRING__DOUBLE (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* VOID:DOUBLE (./gtkmarshalers.list:59) */
+/* VOID:DOUBLE (./gtkmarshalers.list:61) */
 #define _gtk_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE
 
-/* VOID:BOOLEAN (./gtkmarshalers.list:60) */
+/* VOID:BOOLEAN (./gtkmarshalers.list:62) */
 
-/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (./gtkmarshalers.list:61) */
+/* VOID:BOOLEAN,BOOLEAN,BOOLEAN (./gtkmarshalers.list:63) */
 extern void _gtk_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -281,10 +297,10 @@ extern void _gtk_marshal_VOID__BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:BOXED (./gtkmarshalers.list:62) */
+/* VOID:BOXED (./gtkmarshalers.list:64) */
 #define _gtk_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
 
-/* VOID:BOXED,BOXED (./gtkmarshalers.list:63) */
+/* VOID:BOXED,BOXED (./gtkmarshalers.list:65) */
 extern void _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -292,7 +308,7 @@ extern void _gtk_marshal_VOID__BOXED_BOXED (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:BOXED,BOXED,POINTER (./gtkmarshalers.list:64) */
+/* VOID:BOXED,BOXED,POINTER (./gtkmarshalers.list:66) */
 extern void _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -300,7 +316,7 @@ extern void _gtk_marshal_VOID__BOXED_BOXED_POINTER (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* VOID:BOXED,OBJECT (./gtkmarshalers.list:65) */
+/* VOID:BOXED,OBJECT (./gtkmarshalers.list:67) */
 extern void _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -308,7 +324,7 @@ extern void _gtk_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:BOXED,STRING,INT (./gtkmarshalers.list:66) */
+/* VOID:BOXED,STRING,INT (./gtkmarshalers.list:68) */
 extern void _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -316,7 +332,7 @@ extern void _gtk_marshal_VOID__BOXED_STRING_INT (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:BOXED,UINT (./gtkmarshalers.list:67) */
+/* VOID:BOXED,UINT (./gtkmarshalers.list:69) */
 extern void _gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -324,7 +340,7 @@ extern void _gtk_marshal_VOID__BOXED_UINT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:BOXED,UINT,FLAGS (./gtkmarshalers.list:68) */
+/* VOID:BOXED,UINT,FLAGS (./gtkmarshalers.list:70) */
 extern void _gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -332,7 +348,7 @@ extern void _gtk_marshal_VOID__BOXED_UINT_FLAGS (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:BOXED,UINT,UINT (./gtkmarshalers.list:69) */
+/* VOID:BOXED,UINT,UINT (./gtkmarshalers.list:71) */
 extern void _gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -340,9 +356,9 @@ extern void _gtk_marshal_VOID__BOXED_UINT_UINT (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:ENUM (./gtkmarshalers.list:70) */
+/* VOID:ENUM (./gtkmarshalers.list:72) */
 
-/* VOID:ENUM,BOOLEAN (./gtkmarshalers.list:71) */
+/* VOID:ENUM,BOOLEAN (./gtkmarshalers.list:73) */
 extern void _gtk_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -350,7 +366,7 @@ extern void _gtk_marshal_VOID__ENUM_BOOLEAN (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:ENUM,ENUM (./gtkmarshalers.list:72) */
+/* VOID:ENUM,ENUM (./gtkmarshalers.list:74) */
 extern void _gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -358,7 +374,7 @@ extern void _gtk_marshal_VOID__ENUM_ENUM (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:ENUM,FLOAT (./gtkmarshalers.list:73) */
+/* VOID:ENUM,FLOAT (./gtkmarshalers.list:75) */
 extern void _gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -366,7 +382,7 @@ extern void _gtk_marshal_VOID__ENUM_FLOAT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:ENUM,FLOAT,BOOLEAN (./gtkmarshalers.list:74) */
+/* VOID:ENUM,FLOAT,BOOLEAN (./gtkmarshalers.list:76) */
 extern void _gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -374,7 +390,7 @@ extern void _gtk_marshal_VOID__ENUM_FLOAT_BOOLEAN (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:ENUM,INT (./gtkmarshalers.list:75) */
+/* VOID:ENUM,INT (./gtkmarshalers.list:77) */
 extern void _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
                                          GValue       *return_value,
                                          guint         n_param_values,
@@ -382,7 +398,7 @@ extern void _gtk_marshal_VOID__ENUM_INT (GClosure     *closure,
                                          gpointer      invocation_hint,
                                          gpointer      marshal_data);
 
-/* VOID:ENUM,INT,BOOLEAN (./gtkmarshalers.list:76) */
+/* VOID:ENUM,INT,BOOLEAN (./gtkmarshalers.list:78) */
 extern void _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -390,11 +406,11 @@ extern void _gtk_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:INT (./gtkmarshalers.list:77) */
+/* VOID:INT (./gtkmarshalers.list:79) */
 
-/* VOID:INT,INT (./gtkmarshalers.list:78) */
+/* VOID:INT,INT (./gtkmarshalers.list:80) */
 
-/* VOID:INT,INT,BOXED (./gtkmarshalers.list:79) */
+/* VOID:INT,INT,BOXED (./gtkmarshalers.list:81) */
 extern void _gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -402,7 +418,7 @@ extern void _gtk_marshal_VOID__INT_INT_BOXED (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:INT,INT,INT (./gtkmarshalers.list:80) */
+/* VOID:INT,INT,INT (./gtkmarshalers.list:82) */
 extern void _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -410,10 +426,10 @@ extern void _gtk_marshal_VOID__INT_INT_INT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT (./gtkmarshalers.list:81) */
+/* VOID:OBJECT (./gtkmarshalers.list:83) */
 #define _gtk_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:OBJECT,BOOLEAN (./gtkmarshalers.list:82) */
+/* VOID:OBJECT,BOOLEAN (./gtkmarshalers.list:84) */
 extern void _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -421,7 +437,7 @@ extern void _gtk_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED,BOXED (./gtkmarshalers.list:83) */
+/* VOID:OBJECT,BOXED,BOXED (./gtkmarshalers.list:85) */
 extern void _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -429,7 +445,7 @@ extern void _gtk_marshal_VOID__OBJECT_BOXED_BOXED (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED,UINT,UINT (./gtkmarshalers.list:84) */
+/* VOID:OBJECT,BOXED,UINT,UINT (./gtkmarshalers.list:86) */
 extern void _gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
@@ -437,7 +453,7 @@ extern void _gtk_marshal_VOID__OBJECT_BOXED_UINT_UINT (GClosure     *closure,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);
 
-/* VOID:OBJECT,INT (./gtkmarshalers.list:85) */
+/* VOID:OBJECT,INT (./gtkmarshalers.list:87) */
 extern void _gtk_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -445,7 +461,7 @@ extern void _gtk_marshal_VOID__OBJECT_INT (GClosure     *closure,
                                            gpointer      invocation_hint,
                                            gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,OBJECT (./gtkmarshalers.list:86) */
+/* VOID:OBJECT,INT,OBJECT (./gtkmarshalers.list:88) */
 extern void _gtk_marshal_VOID__OBJECT_INT_OBJECT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -453,7 +469,7 @@ extern void _gtk_marshal_VOID__OBJECT_INT_OBJECT (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,INT (./gtkmarshalers.list:87) */
+/* VOID:OBJECT,INT,INT (./gtkmarshalers.list:89) */
 extern void _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -461,7 +477,7 @@ extern void _gtk_marshal_VOID__OBJECT_INT_INT (GClosure     *closure,
                                                gpointer      invocation_hint,
                                                gpointer      marshal_data);
 
-/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./gtkmarshalers.list:88) */
+/* VOID:OBJECT,INT,INT,BOXED,UINT,UINT (./gtkmarshalers.list:90) */
 extern void _gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *closure,
                                                                GValue       *return_value,
                                                                guint         n_param_values,
@@ -469,7 +485,7 @@ extern void _gtk_marshal_VOID__OBJECT_INT_INT_BOXED_UINT_UINT (GClosure     *clo
                                                                gpointer      invocation_hint,
                                                                gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT (./gtkmarshalers.list:89) */
+/* VOID:OBJECT,OBJECT (./gtkmarshalers.list:91) */
 extern void _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -477,7 +493,7 @@ extern void _gtk_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING (./gtkmarshalers.list:90) */
+/* VOID:OBJECT,STRING (./gtkmarshalers.list:92) */
 extern void _gtk_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -485,7 +501,7 @@ extern void _gtk_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING,STRING (./gtkmarshalers.list:91) */
+/* VOID:OBJECT,STRING,STRING (./gtkmarshalers.list:93) */
 extern void _gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                      GValue       *return_value,
                                                      guint         n_param_values,
@@ -493,7 +509,7 @@ extern void _gtk_marshal_VOID__OBJECT_STRING_STRING (GClosure     *closure,
                                                      gpointer      invocation_hint,
                                                      gpointer      marshal_data);
 
-/* VOID:OBJECT,UINT (./gtkmarshalers.list:92) */
+/* VOID:OBJECT,UINT (./gtkmarshalers.list:94) */
 extern void _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -501,7 +517,7 @@ extern void _gtk_marshal_VOID__OBJECT_UINT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,UINT,FLAGS (./gtkmarshalers.list:93) */
+/* VOID:OBJECT,UINT,FLAGS (./gtkmarshalers.list:95) */
 extern void _gtk_marshal_VOID__OBJECT_UINT_FLAGS (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -509,12 +525,12 @@ extern void _gtk_marshal_VOID__OBJECT_UINT_FLAGS (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING (./gtkmarshalers.list:94) */
+/* VOID:OBJECT,STRING (./gtkmarshalers.list:96) */
 
-/* VOID:POINTER (./gtkmarshalers.list:95) */
+/* VOID:POINTER (./gtkmarshalers.list:97) */
 #define _gtk_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:POINTER,INT (./gtkmarshalers.list:96) */
+/* VOID:POINTER,INT (./gtkmarshalers.list:98) */
 extern void _gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -522,7 +538,7 @@ extern void _gtk_marshal_VOID__POINTER_INT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:POINTER,BOOLEAN (./gtkmarshalers.list:97) */
+/* VOID:POINTER,BOOLEAN (./gtkmarshalers.list:99) */
 extern void _gtk_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -530,7 +546,7 @@ extern void _gtk_marshal_VOID__POINTER_BOOLEAN (GClosure     *closure,
                                                 gpointer      invocation_hint,
                                                 gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,BOOLEAN (./gtkmarshalers.list:98) */
+/* VOID:POINTER,POINTER,BOOLEAN (./gtkmarshalers.list:100) */
 extern void _gtk_marshal_VOID__POINTER_POINTER_BOOLEAN (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -538,7 +554,7 @@ extern void _gtk_marshal_VOID__POINTER_POINTER_BOOLEAN (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:POINTER,POINTER,POINTER (./gtkmarshalers.list:99) */
+/* VOID:POINTER,POINTER,POINTER (./gtkmarshalers.list:101) */
 extern void _gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                         GValue       *return_value,
                                                         guint         n_param_values,
@@ -546,7 +562,7 @@ extern void _gtk_marshal_VOID__POINTER_POINTER_POINTER (GClosure     *closure,
                                                         gpointer      invocation_hint,
                                                         gpointer      marshal_data);
 
-/* VOID:POINTER,UINT (./gtkmarshalers.list:100) */
+/* VOID:POINTER,UINT (./gtkmarshalers.list:102) */
 extern void _gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -554,10 +570,10 @@ extern void _gtk_marshal_VOID__POINTER_UINT (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:STRING (./gtkmarshalers.list:101) */
+/* VOID:STRING (./gtkmarshalers.list:103) */
 #define _gtk_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:STRING,STRING (./gtkmarshalers.list:102) */
+/* VOID:STRING,STRING (./gtkmarshalers.list:104) */
 extern void _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -565,9 +581,9 @@ extern void _gtk_marshal_VOID__STRING_STRING (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:STRING,INT,POINTER (./gtkmarshalers.list:103) */
+/* VOID:STRING,INT,POINTER (./gtkmarshalers.list:105) */
 
-/* VOID:STRING,UINT,FLAGS (./gtkmarshalers.list:104) */
+/* VOID:STRING,UINT,FLAGS (./gtkmarshalers.list:106) */
 extern void _gtk_marshal_VOID__STRING_UINT_FLAGS (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -575,7 +591,7 @@ extern void _gtk_marshal_VOID__STRING_UINT_FLAGS (GClosure     *closure,
                                                   gpointer      invocation_hint,
                                                   gpointer      marshal_data);
 
-/* VOID:STRING,UINT,FLAGS,UINT (./gtkmarshalers.list:105) */
+/* VOID:STRING,UINT,FLAGS,UINT (./gtkmarshalers.list:107) */
 extern void _gtk_marshal_VOID__STRING_UINT_FLAGS_UINT (GClosure     *closure,
                                                        GValue       *return_value,
                                                        guint         n_param_values,
@@ -583,7 +599,7 @@ extern void _gtk_marshal_VOID__STRING_UINT_FLAGS_UINT (GClosure     *closure,
                                                        gpointer      invocation_hint,
                                                        gpointer      marshal_data);
 
-/* VOID:UINT,FLAGS,BOXED (./gtkmarshalers.list:106) */
+/* VOID:UINT,FLAGS,BOXED (./gtkmarshalers.list:108) */
 extern void _gtk_marshal_VOID__UINT_FLAGS_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -591,7 +607,7 @@ extern void _gtk_marshal_VOID__UINT_FLAGS_BOXED (GClosure     *closure,
                                                  gpointer      invocation_hint,
                                                  gpointer      marshal_data);
 
-/* VOID:UINT,UINT (./gtkmarshalers.list:107) */
+/* VOID:UINT,UINT (./gtkmarshalers.list:109) */
 extern void _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -599,7 +615,7 @@ extern void _gtk_marshal_VOID__UINT_UINT (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:UINT,STRING (./gtkmarshalers.list:108) */
+/* VOID:UINT,STRING (./gtkmarshalers.list:110) */
 extern void _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -607,7 +623,7 @@ extern void _gtk_marshal_VOID__UINT_STRING (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (./gtkmarshalers.list:109) */
+/* VOID:UINT,BOXED,UINT,FLAGS,FLAGS (./gtkmarshalers.list:111) */
 extern void _gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                             GValue       *return_value,
                                                             guint         n_param_values,
@@ -615,7 +631,7 @@ extern void _gtk_marshal_VOID__UINT_BOXED_UINT_FLAGS_FLAGS (GClosure     *closur
                                                             gpointer      invocation_hint,
                                                             gpointer      marshal_data);
 
-/* VOID:UINT,OBJECT,UINT,FLAGS,FLAGS (./gtkmarshalers.list:110) */
+/* VOID:UINT,OBJECT,UINT,FLAGS,FLAGS (./gtkmarshalers.list:112) */
 extern void _gtk_marshal_VOID__UINT_OBJECT_UINT_FLAGS_FLAGS (GClosure     *closure,
                                                              GValue       *return_value,
                                                              guint         n_param_values,
@@ -623,7 +639,15 @@ extern void _gtk_marshal_VOID__UINT_OBJECT_UINT_FLAGS_FLAGS (GClosure     *closu
                                                              gpointer      invocation_hint,
                                                              gpointer      marshal_data);
 
-/* VOID:VOID (./gtkmarshalers.list:111) */
+/* VOID:VOID (./gtkmarshalers.list:113) */
+
+/* OBJECT:OBJECT,INT,INT (./gtkmarshalers.list:114) */
+extern void _gtk_marshal_OBJECT__OBJECT_INT_INT (GClosure     *closure,
+                                                 GValue       *return_value,
+                                                 guint         n_param_values,
+                                                 const GValue *param_values,
+                                                 gpointer      invocation_hint,
+                                                 gpointer      marshal_data);
 
 G_END_DECLS
 
