@@ -36,6 +36,10 @@
 
 #include "gtkalias.h"
 
+static void            gtk_plug_get_property          (GObject     *object,
+						       guint        prop_id,
+						       GValue      *value,
+						       GParamSpec  *pspec);
 static void            gtk_plug_finalize              (GObject          *object);
 static void            gtk_plug_realize               (GtkWidget        *widget);
 static void            gtk_plug_unrealize             (GtkWidget        *widget);
@@ -64,6 +68,11 @@ typedef struct
   GdkModifierType	 accelerator_mods;
 } GrabbedKey;
 
+enum {
+  PROP_0,
+  PROP_EMBEDDED,
+};
+
 enum {
   EMBEDDED,
   LAST_SIGNAL
@@ -71,7 +80,26 @@ enum {
 
 static guint plug_signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE (GtkPlug, gtk_plug, GTK_TYPE_WINDOW);
+G_DEFINE_TYPE (GtkPlug, gtk_plug, GTK_TYPE_WINDOW)
+
+static void
+gtk_plug_get_property (GObject    *object,
+		       guint       prop_id,
+		       GValue     *value,
+		       GParamSpec *pspec)
+{
+  GtkPlug *plug = GTK_PLUG (object);
+
+  switch (prop_id)
+    {
+    case PROP_EMBEDDED:
+      g_value_set_boolean (value, plug->socket_window != NULL);
+      break;
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
 
 static void
 gtk_plug_class_init (GtkPlugClass *class)
@@ -83,6 +111,7 @@ gtk_plug_class_init (GtkPlugClass *class)
 
   bin_class = g_type_class_peek (GTK_TYPE_BIN);
 
+  gobject_class->get_property = gtk_plug_get_property;
   gobject_class->finalize = gtk_plug_finalize;
   
   widget_class->realize = gtk_plug_realize;
@@ -104,6 +133,28 @@ gtk_plug_class_init (GtkPlugClass *class)
   window_class->set_focus = gtk_plug_set_focus;
   window_class->keys_changed = gtk_plug_keys_changed;
 
+  /**
+   * GtkPlug:embedded:
+   *
+   * %TRUE if the plug is embedded in a socket.
+   *
+   * Since: 2.12
+   */
+  g_object_class_install_property (gobject_class,
+				   PROP_EMBEDDED,
+				   g_param_spec_boolean ("embedded",
+							 P_("Embedded"),
+							 P_("Whether or not the plug is embedded"),
+							 FALSE,
+							 GTK_PARAM_READABLE));
+
+  /**
+   * GtkPlug::embedded:
+   * @plug: the object on which the signal was emitted
+   *
+   * Gets emitted when the plug becomes embedded in a socket
+   * and when the embedding ends.
+   */ 
   plug_signals[EMBEDDED] =
     g_signal_new (I_("embedded"),
 		  G_OBJECT_CLASS_TYPE (class),
@@ -378,8 +429,11 @@ gtk_plug_construct_for_display (GtkPlug         *plug,
 	    }
 	}
 
-      if (plug->socket_window)
+      if (plug->socket_window) {
 	g_signal_emit (plug, plug_signals[EMBEDDED], 0);
+
+        g_object_notify (G_OBJECT (plug), "embedded");
+      }
     }
 }
 
@@ -449,6 +503,8 @@ gtk_plug_unrealize (GtkWidget *widget)
       gdk_window_set_user_data (plug->socket_window, NULL);
       g_object_unref (plug->socket_window);
       plug->socket_window = NULL;
+
+      g_object_notify (G_OBJECT (widget), "embedded");
     }
 
   if (!plug->same_app)
