@@ -297,6 +297,8 @@ gtk_scale_button_class_init (GtkScaleButtonClass *klass)
 
   gtk_binding_entry_add_signal (binding_set, GDK_space, 0,
 				"popup", 0);
+  gtk_binding_entry_add_signal (binding_set, GDK_KP_Space, 0,
+				"popup", 0);
   gtk_binding_entry_add_signal (binding_set, GDK_Return, 0,
 				"popup", 0);
   gtk_binding_entry_add_signal (binding_set, GDK_ISO_Enter, 0,
@@ -877,6 +879,9 @@ gtk_scale_button_grab_notify (GtkScaleButton *button,
 
   priv = button->priv;
 
+  if (!GTK_WIDGET_HAS_GRAB (priv->dock))
+    return;
+
   if (gtk_widget_is_ancestor (gtk_grab_get_current (), priv->dock))
     return;
 
