@@ -55,10 +55,14 @@ struct _GtkToolItemClass
   /* signals */
   gboolean   (* create_menu_proxy)    (GtkToolItem *tool_item);
   void       (* toolbar_reconfigured) (GtkToolItem *tool_item);
+#ifndef GTK_DISABLE_DEPRECATED
   gboolean   (* set_tooltip)	      (GtkToolItem *tool_item,
 				       GtkTooltips *tooltips,
 				       const gchar *tip_text,
 				       const gchar *tip_private);
+#else
+  gpointer _set_tooltip;
+#endif
 
   /* Padding for future expansion */
   void (* _gtk_reserved1) (void);
@@ -67,7 +71,7 @@ struct _GtkToolItemClass
   void (* _gtk_reserved4) (void);
 };
 
-GType        gtk_tool_item_get_type (void);
+GType        gtk_tool_item_get_type (void) G_GNUC_CONST;
 GtkToolItem *gtk_tool_item_new      (void);
 
 void            gtk_tool_item_set_homogeneous          (GtkToolItem *tool_item,
@@ -78,22 +82,28 @@ void            gtk_tool_item_set_expand               (GtkToolItem *tool_item,
 							gboolean     expand);
 gboolean        gtk_tool_item_get_expand               (GtkToolItem *tool_item);
 
+#ifndef GTK_DISABLE_DEPRECATED
 void            gtk_tool_item_set_tooltip              (GtkToolItem *tool_item,
 							GtkTooltips *tooltips,
 							const gchar *tip_text,
 							const gchar *tip_private);
+#endif /* GTK_DISABLE_DEPRECATED */
+void            gtk_tool_item_set_tooltip_text         (GtkToolItem *tool_item,
+							const gchar *text);
+void            gtk_tool_item_set_tooltip_markup       (GtkToolItem *tool_item,
+							const gchar *markup);
 
-void            gtk_tool_item_set_use_drag_window      (GtkToolItem *toolitem,
+void            gtk_tool_item_set_use_drag_window      (GtkToolItem *tool_item,
 							gboolean     use_drag_window);
-gboolean        gtk_tool_item_get_use_drag_window      (GtkToolItem *toolitem);
+gboolean        gtk_tool_item_get_use_drag_window      (GtkToolItem *tool_item);
 
-void            gtk_tool_item_set_visible_horizontal   (GtkToolItem *toolitem,
+void            gtk_tool_item_set_visible_horizontal   (GtkToolItem *tool_item,
 							gboolean     visible_horizontal);
-gboolean        gtk_tool_item_get_visible_horizontal   (GtkToolItem *toolitem);
+gboolean        gtk_tool_item_get_visible_horizontal   (GtkToolItem *tool_item);
 
-void            gtk_tool_item_set_visible_vertical     (GtkToolItem *toolitem,
+void            gtk_tool_item_set_visible_vertical     (GtkToolItem *tool_item,
 							gboolean     visible_vertical);
-gboolean        gtk_tool_item_get_visible_vertical     (GtkToolItem *toolitem);
+gboolean        gtk_tool_item_get_visible_vertical     (GtkToolItem *tool_item);
 
 gboolean        gtk_tool_item_get_is_important         (GtkToolItem *tool_item);
 void            gtk_tool_item_set_is_important         (GtkToolItem *tool_item,
