@@ -28,6 +28,7 @@
 #include <math.h>
 #include <string.h>
 #include "gtkvruler.h"
+#include "gtkintl.h"
 #include "gtkalias.h"
 
 #include <glib/gprintf.h>
@@ -41,40 +42,12 @@
 #define ROUND(x) ((int) ((x) + 0.5))
 
 
-static void gtk_vruler_class_init    (GtkVRulerClass *klass);
-static void gtk_vruler_init          (GtkVRuler      *vruler);
 static gint gtk_vruler_motion_notify (GtkWidget      *widget,
 				      GdkEventMotion *event);
 static void gtk_vruler_draw_ticks    (GtkRuler       *ruler);
 static void gtk_vruler_draw_pos      (GtkRuler       *ruler);
 
-
-GType
-gtk_vruler_get_type (void)
-{
-  static GType vruler_type = 0;
-
-  if (!vruler_type)
-    {
-      static const GTypeInfo vruler_info =
-      {
-	sizeof (GtkVRulerClass),
-	NULL,		/* base_init */
-	NULL,		/* base_finalize */
-	(GClassInitFunc) gtk_vruler_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	sizeof (GtkVRuler),
-	0,		/* n_preallocs */
-	(GInstanceInitFunc) gtk_vruler_init,
-      };
-
-      vruler_type = g_type_register_static (GTK_TYPE_RULER, "GtkVRuler",
-					    &vruler_info, 0);
-    }
-
-  return vruler_type;
-}
+G_DEFINE_TYPE (GtkVRuler, gtk_vruler, GTK_TYPE_RULER)
 
 static void
 gtk_vruler_class_init (GtkVRulerClass *klass)
@@ -117,10 +90,8 @@ gtk_vruler_motion_notify (GtkWidget      *widget,
 
   ruler = GTK_RULER (widget);
 
-  if (event->is_hint)
-    gdk_window_get_pointer (widget->window, NULL, &y, NULL);
-  else
-    y = event->y;
+  gdk_event_request_motions (event);
+  y = event->y;
 
   ruler->position = ruler->lower + ((ruler->upper - ruler->lower) * y) / widget->allocation.height;
   g_object_notify (G_OBJECT (ruler), "position");
@@ -191,7 +162,8 @@ gtk_vruler_draw_ticks (GtkRuler *ruler)
   lower = ruler->lower / ruler->metric->pixels_per_unit;
 
   if ((upper - lower) == 0)
-    return;
+    goto out;
+
   increment = (gdouble) width / (upper - lower);
 
   /* determine the scale
@@ -273,6 +245,7 @@ gtk_vruler_draw_ticks (GtkRuler *ruler)
     }
 
   cairo_fill (cr);
+out:
   cairo_destroy (cr);
 
   g_object_unref (layout);
